@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.2000';
+our $VERSION = '0.2001';
 
 use strictures 2;
 use List::SomeUtils qw(any first_index);
@@ -270,10 +270,10 @@ sub get_scale_degree {
     elsif ( $roman =~ /^ii/i ) {
         $degree = 2;
     }
-    if ( $roman =~ /o/ ) {
+    if ( $roman =~ /o$/ ) {
         $type = 'diminished';
     }
-    elsif ( $roman =~ /^[ivo]+$/ ) {
+    elsif ( $roman =~ /^[iv]+$/ ) {
         $type = 'minor';
     }
     return $degree, $type;
@@ -394,7 +394,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.2000
+version 0.2001
 
 =head1 SYNOPSIS
 
@@ -554,7 +554,7 @@ Return the Roman representation of the mode.
 
 =head2 get_scale_degree
 
-  ($degree, $type) = $mtr->get_scale_nums($roman);
+  ($degree, $type) = $mtr->get_scale_degree($roman);
 
 Return the (Arabic) scale degree number and C<major>, C<minor>,
 C<diminished> chord types, given the Roman representation of the mode
